from setuptools import setup

setup(
    name='wizata_test_lib',
    version="0.1",
    description='Wizata Sample Library',
    author='Wizata S.A.',
    author_email='info@wizata.com',
    packages=['wizata_test_lib']
)
